@@ -29,7 +29,6 @@
 #include <kpushbutton.h>
 #include <tdelistview.h>
 #include <tdefileitem.h>
-#include <tdeglobalsettings.h>
 #include <tqpushbutton.h>
 #include <tqcombobox.h>
 
@@ -59,11 +58,10 @@ public slots:
 
 private:
   TDEAboutData *myAboutData;
-  TDEGlobalSettings *kgs;
-    KPushButton* btnAdd;
-    TDEListView* listCMD;
-    KPushButton* btnRemove;
-    TQPushButton* btnProperties;
+  KPushButton* btnAdd;
+  TDEListView* listCMD;
+  KPushButton* btnRemove;
+  TQPushButton* btnProperties;
   TQComboBox* cmbStartOn;
 };
 
